==> mgetty_0.99.2.orig.tar.gz: mgetty-0.99.2.orig/voice/libvoice/open.c <==
/*
 * open.c
 *
 * Try all available voice devices and open the first one that
 * suceeds and initialize it.
 *
 */

#include "../include/voice.h"

char *libvoice_open_c = "$Id: open.c,v 1.5 1996/07/25 19:23:25 marc Exp $";

int voice_open_device _P0(void)
     {
     char *voice_tty_start;
     char *voice_tty_end;
     char voice_tty[VOICE_BUF_LEN];

     lprintf(L_MESG, "opening voice modem device");

     if (strlen(cvd.voice_devices.d.p) == 0)
          {
          lprintf(L_FATAL,
           "no voice modem devices configured in config file");
          exit(FAIL);
          };

     lprintf(L_NOISE, "voice open '%s'", cvd.voice_devices.d.p);
     voice_tty_start = cvd.voice_devices.d.p;

     do
          {
          voice_tty_end = strchr(voice_tty_start, ':');
          sprintf(voice_tty, "/dev/");

          if (voice_tty_end != NULL)
               strncat(voice_tty, voice_tty_start, voice_tty_end -
                voice_tty_start);
          else
               strcat(voice_tty, voice_tty_start);

          lprintf(L_JUNK, "trying device '%s'", voice_tty);

          if (makelock(&voice_tty[5]) == OK)
               {

               if ((voice_fd = open(voice_tty, O_RDWR | O_NDELAY | O_NOCTTY))
                == FAIL)
                    {
                    lprintf(L_ERROR, "error opening %s", voice_tty);
                    rmlocks();
                    voice_fd = NO_VOICE_FD;
                    }
               else
                    {

                    /*
                     * unset O_NDELAY (otherwise waiting for characters
                     * would be "busy waiting", eating up all cpu)
                     */

                    if (fcntl(voice_fd, F_SETFL, O_RDWR) == FAIL)
                         {
                         lprintf(L_ERROR, "error in fcntl");
                         close(voice_fd);
                         rmlocks();
                         voice_fd = NO_VOICE_FD;
                         }
                    else
                         lprintf(L_MESG, "opened voice modem device %s",
                          voice_tty);

                    };

               };

          voice_tty_start = voice_tty_end + 1;
          }
     while ((voice_tty_end != NULL) && (voice_fd == NO_VOICE_FD));

     if (voice_fd != NO_VOICE_FD)
          {
          char config_file[VOICE_BUF_LEN];

          make_path(config_file, CONF_DIR, VOICE_CONFIG_FILE);
          lprintf(L_MESG, "reading port %s configuration from config file %s",
           &voice_tty[5], config_file);
          get_config(config_file, (conf_data *) &cvd, "port", &voice_tty[5]);
          return(voice_init());
          };

     return(FAIL);
     };

==> mgetty_1.1.8.orig.tar.gz: mgetty-1.1.8/voice/libvoice/open.c <==
/*
 * open.c
 *
 * Try all available voice devices and open the first one that
 * suceeds and initialize it.
 *
 */

#include "../include/voice.h"

char *libvoice_open_c = "$Id: open.c,v 1.8 1997/01/14 06:50:22 marc Exp $";

int voice_open_device _P0(void)
     {
     char *voice_tty_start;
     char *voice_tty_end;
     char voice_tty[VOICE_BUF_LEN];

     lprintf(L_MESG, "opening voice modem device");

     if (strlen(cvd.voice_devices.d.p) == 0)
          {
          lprintf(L_FATAL,
           "no voice modem devices configured in config file");
          exit(FAIL);
          };

     lprintf(L_NOISE, "voice open '%s'", cvd.voice_devices.d.p);
     voice_tty_start = cvd.voice_devices.d.p;

     do
          {
          voice_tty_end = strchr(voice_tty_start, ':');
          sprintf(voice_tty, "/dev/");

          if (voice_tty_end != NULL)
               strncat(voice_tty, voice_tty_start, voice_tty_end -
                voice_tty_start);
          else
               strcat(voice_tty, voice_tty_start);

          lprintf(L_JUNK, "trying device '%s'", voice_tty);

          if (makelock(&voice_tty[5]) == OK)
               {

               if ((voice_fd = open(voice_tty, O_RDWR | O_NDELAY | O_NOCTTY))
                == FAIL)
                    {
                    lprintf(L_ERROR, "error opening %s", voice_tty);
                    rmlocks();
                    voice_fd = NO_VOICE_FD;
                    }
               else
                    {

                    /*
                     * unset O_NDELAY (otherwise waiting for characters
                     * would be "busy waiting", eating up all cpu)
                     */

                    if (fcntl(voice_fd, F_SETFL, O_RDWR) == FAIL)
                         {
                         lprintf(L_ERROR, "error in fcntl");
                         close(voice_fd);
                         rmlocks();
                         voice_fd = NO_VOICE_FD;
                         }
                    else
                         lprintf(L_MESG, "opened voice modem device %s",
                          voice_tty);

                    };

               };

          voice_tty_start = voice_tty_end + 1;
          }
     while ((voice_tty_end != NULL) && (voice_fd == NO_VOICE_FD));

     if (voice_fd != NO_VOICE_FD)
          {
          DevID = malloc(strlen(voice_tty) + 1);
          strcpy(DevID, voice_tty);
          lprintf(L_MESG, "reading port %s configuration from config file %s",
           &voice_tty[5], voice_config_file);
          get_config(voice_config_file, (conf_data *) &cvd, "port",
           &voice_tty[5]);
          return(voice_init());
          };

     return(FAIL);
     }
